@@ -4,10 +4,9 @@ use parent 'Class::Property::RW';
 
 sub TIESCALAR
 {
-    my( $class, $object, $field, $init, $flag_ref ) = @_;
+    my( $class, $field, $init, $flag_ref ) = @_;
     return bless \{
-        'object' => $object
-        , 'field' => $field
+        'field' => $field
         , 'init' => $init
         , 'flag_ref' => $flag_ref
     }, $class;
@@ -17,7 +16,7 @@ sub STORE
 {
     my( $self, $value ) = @_;
     ${$self}->{'object'}->{${$self}->{'field'}} = $value;
-    ${${$self}->{'flag_ref'}}++ unless ${${$self}->{'flag_ref'}};
+    ${${$self}->{'flag_ref'}}++;
     return;
 }
 
